.. _getting-started:

Quick start
===========

Topics of the section:

- Installing
- Minimal example

Installing
----------

Install the package from `PyPI <https://pypi.org/project/rocketry/>`_:

.. code-block:: console

    pip install rocketry

Minimal Example
---------------

Next, we make a quick and minimal application:

.. literalinclude:: /code/demos/minimal.py
    :language: py

We initialized the Rocketry application, created one task
which runs every day and then we started the app.
This is nothing fancy but gets you stared. 

What next
^^^^^^^^^

This is only a small slice what Rocketry has to offer. Read further 
to explore the features.
